@@ -32,9 +32,9 @@ model.connect()
 class TestModel(TestCase):
     def setUp(self):
         model.resync()
-        model.metadata.create_all()
+        model.create_all()
     def tearDown(self):
-        model.metadata.drop_all()
+        model.drop_all()
 
 class TestController(TestModel):
     def __init__(self, *args):
